/* ============================================================================
 * Project Name: DMA_3phase_VDAC_01b
 *
 * Description:
 *   PSoC5 demo showing 3-phase analog sine output generator
 *   with variable frequency and amplitude.
 *   Project uses DMA to transfer sine data from RAM buffer to VDAC_1, 2, 3
 *   to produce 120-degree shifted sine voltage.
 *
 *   Frequency range [1kHz to 10kHz], resolution 32-bit (~0.01 Hz)
 *   Amplitude range [0V to 4V p-p], resolution 8-bit (~0.015V)
 *    
 *   Frequency adjustment achieved using DDS32 as DMA clock
 *   Amplitude adjustment achived by re-calculating RAM Buffer values
 *
 *   Rotary encoder is used to adjust frequency and amplitude.
 *
 * Uses:
 *   project uses several custom components:
 *
 *   DDS_sw 0.0_beta (included in the project)
 *
 *   DDS32 v0.1   
 *   https://community.cypress.com/t5/Code-Examples/DDS24-24-bit-DDS-arbitrary-frequency-generator-component/m-p/46587/highlight/true#M155

 *   QuadDec_SW 0.1
 *   https://community.cypress.com/t5/Code-Examples/Quad-Decoder-with-Button-Switch-component-for-rotary-shaft/td-p/121267
 *
 *   PSoC Annotation Library 1.0
 *   https://community.cypress.com/t5/Code-Examples/PSoC-Annotation-Library-v1-0/m-p/62657#M245
 *
 *   Sync32 v0.0
 *   https://community.cypress.com/t5/Code-Examples/Sync32-custom-component-for-PSoC5-and-PSoC4/m-p/31243
 *
 * ============================================================================
 * PROVIDED AS-IS, NO WARRANTY OF ANY KIND, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 * FREE TO SHARE, USE AND MODIFY UNDER TERMS: CREATIVE COMMONS - SHARE ALIKE
 * ============================================================================
*/

#include <project.h>
#include <WaveGen.h>


#define BlinkLED(); {Pin_LED_Write(1); CyDelayUs(50); Pin_LED_Write(0);} // blink LED indicator


//===========================================
// Global variables
//===========================================

//===========================================
// Forward declarations
//===========================================


void Initialize()
{
    CyGlobalIntEnable;

    WaveTable_1_SetClock(WaveGen_NumSamples); // WaveGen_NumSamples defined in WaveGen.h
    WaveTable_1_Start();
    //WaveTable_1_SetAmplitude(Decoder_1_Position);

    WaveGen_Start();                  // start wave generator and fill Buffer with default values

    Opamp_1_Start();                      
    Opamp_2_Start();                      
    Opamp_3_Start();                      
    
    VDAC_1_Start();                      
    VDAC_2_Start();                      
    VDAC_3_Start();   
    
    Decoder_1_Start();
    
    DDS_1_Start();                          // start DDS
    //DDS_1_SetFrequency((float) WaveGen_NumSamples * Decoder_1_Position); // update frequency
    
}

int main(void)
{
    
    Initialize();
    

    for(;;) //forever
    {
        
        /*
        if (Decoder_1_PositionChanged)
        {
            BlinkLED();
            WaveTable_1_SetAmplitude(Decoder_1_Position); // update amplitude
            WaveGen_CreateWave(0, 0);    // fill Buffer with new values       
        }
        */
        
        
        if (Decoder_1_PositionChanged)
        {
            BlinkLED();
            DDS_1_SetFrequency((float) WaveGen_NumSamples * Decoder_1_Position); // update frequency
        }
        
        
        if (Decoder_1_BtnPressed)
        {
            BlinkLED();
            Decoder_1_SetPosition(Decoder_1_StartPosition);
        }
    }
    
}




/* [] END OF FILE */

